@@ -1,6 +1,6 @@
 /*BINFMTC:
  *  parameter handling for cpbuilder.
- *  Copyright (C) 2007 Junichi Uekawa
+ *  Copyright (C) 2007-2008 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -130,6 +130,18 @@ int load_config_file(const char* config, pbuilderconfig* pc)
 	    {
 	      pc->debbuildopts=strdup(delim);
 	    }
+	  else if (!strcmp(buf, "NO_COWDANCER_UPDATE"))
+	    {
+	      pc->no_cowdancer_update=1;
+	    }
+	  else if (!strcmp(buf, "DEBIAN_ETCH_WORKAROUND"))
+	    {
+	      pc->debian_etch_workaround=1;
+	    }
+	  else if (!strcmp(buf, "ARCH_DISKDEVICE"))
+	    {
+	      pc->arch_diskdevice=strdup(delim);
+	    }
 	}
     }
 
@@ -157,14 +169,20 @@ int cpbuilder_dumpconfig(pbuilderconfig* pc)
   DUMPINT(mountdev);
   DUMPINT(mountdevpts);
   DUMPINT(save_after_login);
-  DUMPINT(memory_megs);
+
   DUMPSTR(buildplace);
   DUMPSTR(buildresult);
   DUMPSTR(basepath);
   DUMPSTR(mirror);
   DUMPSTR(distribution);
+  DUMPSTR(components);
+  DUMPSTR(debbuildopts);
+
+  DUMPINT(no_cowdancer_update);
+  
   DUMPSTR(kernel_image);
   DUMPSTR(initrd);
+  DUMPINT(memory_megs);
   DUMPSTR(arch);
   return 0;
 }
@@ -205,6 +223,13 @@ int parse_parameter(int ac, char** av,
     {"components", required_argument, 0, 0},
     {"debbuildopts", required_argument, 0, 0},
 
+    /* cowbuilder specific options */
+    {"no-cowdancer-update", no_argument, 0, 0},
+    {"debian-etch-workaround", no_argument, 0, 0},
+
+    /* qemubuilder specific options */
+    {"arch-diskdevice", no_argument, 0, 0},
+
     /* verbatim options, synced as of pbuilder 0.153 */
     {"othermirror", required_argument, 0, 'M'},
     {"http-proxy", required_argument, 0, 'M'},
@@ -340,6 +365,18 @@ int parse_parameter(int ac, char** av,
 	    {
 	      pc.distribution=strdup(optarg);
 	    }
+	  else if (!strcmp(long_options[index_point].name,"no-cowdancer-update"))
+	    {
+	      pc.no_cowdancer_update=1;
+	    }
+	  else if (!strcmp(long_options[index_point].name,"debian-etch-workaround")) 
+	    {
+	      pc.debian_etch_workaround=1;
+	    }
+	  else if (!strcmp(long_options[index_point].name,"arch-diskdevice"))
+	    {
+	      pc.arch_diskdevice=strdup(optarg);
+	    }
 	  else if (!strcmp(long_options[index_point].name,"components"))
 	    {
 	      /* this is for qemubuilder */
@@ -405,18 +442,43 @@ int parse_parameter(int ac, char** av,
   switch(pc.operation)
     {
     case pbuilder_build:
+      if (!av[optind])
+	{
+	  /* parameter missing */
+	  fprintf(stderr, "E: parameter missing for build operation\n");
+	  return 1;
+	}
+      
       return cpbuilder_build(&pc, av[optind]);
       
     case pbuilder_create:
+      if (av[optind])
+	{
+	  /* extra parameter */
+	  fprintf(stderr, "E: too many parameters for create\n");
+	  return 1;
+	}
       return cpbuilder_create(&pc);
       
     case pbuilder_update:
+      if (av[optind])
+	{
+	  /* extra parameter */
+	  fprintf(stderr, "E: too many parameters for update\n");
+	  return 1;
+	}
       return cpbuilder_update(&pc);
       
     case pbuilder_login:
       return cpbuilder_login(&pc);
 
     case pbuilder_execute:
+      if (!av[optind])
+	{
+	  /* parameter missing */
+	  fprintf(stderr, "E: parameter missing for execute operation\n");
+	  return 1;
+	}
       return cpbuilder_execute(&pc, &av[optind]);
 
     case pbuilder_help:
