@@ -1,6 +1,6 @@
 /*BINFMTC:
  *  parameter handling for cpbuilder.
- *  Copyright (C) 2007 Junichi Uekawa
+ *  Copyright (C) 2007-2008 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,12 +32,17 @@ typedef struct pbuilderconfig
   char* distribution;
   char* components;
   char* debbuildopts;
+  
+  /* cow-specific options */
+  int no_cowdancer_update;		/* --no-cowdancer-update */
+  int debian_etch_workaround;		/* --debian-etch-workaround */
 
   /* more qemu-isque options */
   char* kernel_image;
   char* initrd;
   int memory_megs;		/* megabytes of memory */
   char* arch;
+  char* arch_diskdevice;
 
   enum {
     pbuilder_do_nothing=0,
