@@ -1,6 +1,6 @@
 /*BINFMTC: parameter.c forkexec.c
  *  qemubuilder: pbuilder with qemu
- *  Copyright (C) 2007 Junichi Uekawa
+ *  Copyright (C) 2007-2008 Junichi Uekawa
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,7 +50,8 @@ const char* qemu_keyword="END OF WORK EXIT CODE=";
  */
 static const char* qemu_arch_serialdevice(const char* arch)
 {
-  if (!strcmp(arch, "arm"))
+  if (!strcmp(arch, "arm") || 
+      !strcmp(arch, "armel"))
     {
       return "mknod dev/console c 204 64; ";
     }
@@ -60,9 +61,13 @@ static const char* qemu_arch_serialdevice(const char* arch)
 /**
  * arch-specific routine; disk device name to use
  */
-static const char* qemu_arch_diskdevice(const char* arch)
+static const char* qemu_arch_diskdevice(const struct pbuilderconfig* pc)
 {
-  if (!strcmp(arch, "arm"))
+  if (pc->arch_diskdevice)
+    return pc->arch_diskdevice;
+
+  if (!strcmp(pc->arch, "arm") || 
+      !strcmp(pc->arch, "armel"))
     {
       return "sd";
     }
@@ -74,7 +79,8 @@ static const char* qemu_arch_diskdevice(const char* arch)
  */
 static const char* qemu_arch_qemu(const char* arch)
 {
-  if (!strcmp(arch, "arm"))
+  if (!strcmp(arch, "arm") || 
+      !strcmp(arch, "armel"))
     {
       return "qemu-system-arm";
     }
@@ -113,7 +119,8 @@ static const char* qemu_arch_qemu(const char* arch)
  */
 static const char* qemu_arch_qemumachine(const char* arch)
 {
-  if (!strcmp(arch, "arm"))
+  if (!strcmp(arch, "arm") || 
+      !strcmp(arch, "armel"))
     return "versatilepb";
   else if (!strcmp(arch, "i386") ||
 	   !strcmp(arch, "amd64"))
@@ -126,13 +133,14 @@ static const char* qemu_arch_qemumachine(const char* arch)
   return NULL;
 }
 
-
 /**
  * arch-specific routine; the serial device
  */
 static const char* qemu_arch_tty(const char* arch)
 {
-  if (!strcmp(arch, "arm"))
+
+  if (!strcmp(arch, "arm")||
+      !strcmp(arch, "armel"))
     {
       return "ttyAMA0";
     }
@@ -236,8 +244,6 @@ static int create_script(const char* mountpoint, const char* relative_path, cons
   return ret;
 }
 
-
-
 /**
    copy file contents to temporary filesystem, so that it can be used inside qemu.
  */
@@ -278,7 +284,6 @@ static int copy_file_internal(const char* orig, const char*dest)
   return ret;
 }
 
-
 /* minimally fix terminal I/O */
 static void fix_terminal(void)
 {
@@ -364,7 +369,10 @@ static int fork_qemu(const char* hda, const char* hdb, const struct pbuilderconf
 			printf("   -> successfully killed qemu\n");
 		      else
 			perror("   -> failed to kill qemu? :");
-		      waitpid(child, &status, 0);
+		      if (-1==waitpid(child, &status, 0))
+			{
+			  perror("qemubuilder: waitpid");
+			}
 		      break;
 		    }
 		  write(1,buf,count);
@@ -396,7 +404,7 @@ static int fork_qemu(const char* hda, const char* hdb, const struct pbuilderconf
       
       asprintf(&append_command,
 	       "root=/dev/%sa init=/pbuilder-run console=%s",
-	       qemu_arch_diskdevice(pc->arch),
+	       qemu_arch_diskdevice(pc),
 	       qemu_arch_tty(pc->arch));
             
       dup2(sp[1],1);
@@ -723,7 +731,6 @@ int cpbuilder_create(const struct pbuilderconfig* pc)
     }
   free(s);
   
-  /* this 'sdb' part is arch specific. */
   asprintf(&s,
 	   "#!/bin/bash\n"
 	   "echo \n"
@@ -736,10 +743,9 @@ int cpbuilder_create(const struct pbuilderconfig* pc)
 	   "mkdir -p $PBUILDER_MOUNTPOINT\n"
 	   "mount -n -t ext3 /dev/%sb $PBUILDER_MOUNTPOINT \n"
 	   "$PBUILDER_MOUNTPOINT/pbuilder-run \n",
-	   qemu_arch_diskdevice(pc->arch)
+	   qemu_arch_diskdevice(pc)
 	   );
   
-  
   create_script(pc->buildplace, 
 		"pbuilder-run",
 		s);
@@ -761,6 +767,7 @@ int cpbuilder_create(const struct pbuilderconfig* pc)
 	   "echo ' -> qemu-pbuilder second-stage' \n"
 	   "/debootstrap/debootstrap --second-stage\n"
 	   "echo deb %s %s %s > /etc/apt/sources.list \n"
+	   "echo 'APT::Install-Recommends \"false\"; ' > /etc/apt/apt.conf.d/15pbuilder\n"
 	   //TODO: copy hook scripts
 	   "mount -n /proc /proc -t proc\n"
 	   "dhclient eth0\n"
